package com.fjhx.item.controller.product;

import com.baomidou.dynamic.datasource.annotation.DS;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.fjhx.common.constant.SourceConstant;
import com.fjhx.item.entity.product.dto.ProductInfoDto;
import com.fjhx.item.entity.product.dto.ProductInfoSelectDto;
import com.fjhx.item.entity.product.po.ProductInfo;
import com.fjhx.item.entity.product.vo.ProductInfoVo;
import com.fjhx.item.service.product.ProductInfoService;
import com.ruoyi.common.core.domain.BaseSelectDto;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;

import java.util.List;
import java.util.Map;


/**
 * <p>
 * 产品库 前端控制器
 * </p>
 *
 * @author zlj
 * @since 2023-03-17
 */
@DS(SourceConstant.ITEM)
@RestController
@RequestMapping("/productInfo")
public class ProductInfoController {

    @Autowired
    private ProductInfoService productInfoService;

    /**
     * 产品库分页
     */
    @PostMapping("/page")
    public Page<ProductInfoVo> page(@RequestBody ProductInfoSelectDto dto) {
        return productInfoService.getPage(dto);
    }

    /**
     * 产品库分页 维多利亚
     */
    @PostMapping("/pageByWdly")
    public Page<ProductInfoVo> pageByWdly(@RequestBody ProductInfoSelectDto dto) {
        return productInfoService.getPageByWdly(dto);
    }

    /**
     * 产品库组合产品分页
     */
    @PostMapping("/getCombinationPage")
    public Page<ProductInfoVo> getCombinationPage(@RequestBody ProductInfoSelectDto dto) {
        return productInfoService.getCombinationPage(dto);
    }

    /**
     * 产品库明细
     */
    @PostMapping("/detail")
    public ProductInfoVo detail(@RequestBody BaseSelectDto dto) {
        return productInfoService.detail(dto.getId());
    }

    /**
     * 产品库新增
     */
    @PostMapping("/add")
    public void add(@RequestBody ProductInfoDto productInfoDto) {
        productInfoService.add(productInfoDto);
    }

    /**
     * 产品库新增 维多利亚
     */
    @PostMapping("/addByWdly")
    public void addByWdly(@RequestBody ProductInfoDto productInfoDto) {
        productInfoService.addByWdly(productInfoDto);
    }

    /**
     * 产品库编辑
     */
    @PostMapping("/edit")
    public void edit(@RequestBody ProductInfoDto productInfoDto) {
        productInfoService.edit(productInfoDto);
    }

    /**
     * 产品库删除
     */
    @PostMapping("/delete")
    public void delete(@RequestBody BaseSelectDto dto) {
        productInfoService.delete(dto.getId());
    }

    @PostMapping("/excelImport")
    public void issueExcelImport(@RequestParam("file") MultipartFile file) {
        productInfoService.excelImport(file);
    }

    /**
     * 产品部门移交 维多利亚
     */
    @PostMapping("/transfer")
    public void transfer(@RequestBody ProductInfoDto productInfoDto) {
        productInfoService.transfer(productInfoDto);
    }


    /**
     * 产品统计（数据看板-产品分析页面）
     * @param productInfoDto
     */
    @PostMapping("/productStatistics")
    public Map<String, Object> productStatistics(@RequestBody ProductInfoDto productInfoDto) {
        return productInfoService.productStatistics(productInfoDto);
    }

    /**
     * 产品分布（数据看板-产品分析页面）
     * @param productInfoDto
     */
    @PostMapping("/productDistribution")
    public List<ProductInfo> productDistribution(@RequestBody ProductInfoDto productInfoDto) {
       return productInfoService.productDistribution(productInfoDto);
    }

    /**
     * 产品类型排行（数据看板-产品分析页面）
     * @param productInfoDto
     */
    @PostMapping("/productTypeRanking")
    public Page<ProductInfoVo> productTypeRanking(@RequestBody ProductInfoSelectDto productInfoDto) {
        return productInfoService.productTypeRanking(productInfoDto);
    }

    /**
     * 产品排行（数据看板-产品分析页面）
     * @param productInfoDto
     */
    @PostMapping("/productRanking")
    public Page<ProductInfoVo> productRanking(@RequestBody ProductInfoSelectDto productInfoDto) {
        return productInfoService.productRanking(productInfoDto);
    }

}
